@@ -9,12 +9,14 @@ from vsource.algorithms.face_detection import face_detection
 from vsource.algorithms.face_attribute import face_attribute
 from vsource.algorithms.speaker_recognition import speaker_recognition
 from vsource.algorithms.face_generation import face_generation
+from vsource.algorithms.random_number import random_number
 
 from vsource.algorithms.new_algorithm import new_algorithm
+from vsource.algorithms.cod_cpd import cod_cpd
 
 from vsource.scripts.algorithm_scripts.algorithms import parse_algorithm
 from vsource.scripts.enroll_service import enroll
 
-__version__ = 'v1.0.6'
+__version__ = 'v1.0.11'
 __author__  = 'Ecohnoch'
 __email__   = '542305306@qq.com'
\ No newline at end of file
