@@ -41,6 +41,7 @@ class AlgorithmContainerConfigParser:
                     f.write('\n')
                 f.write("redis\n")
                 f.write('kafka-python\n')
+                f.write('requests\n')
             print('[Step 1/6] Requirements has been successfully generated!')
         except Exception as e:
             err_msg = traceback.format_exc()
@@ -91,7 +92,7 @@ class AlgorithmContainerConfigParser:
             for each_input_param_name in self.input_params:
                 param_init_lines += ('            {} = info_dict[\'{}\']\n'.format(each_input_param_name, each_input_param_name))
                 if self.input_params[each_input_param_name]['type'] == 'path':
-                    param_init_lines += ('            {} = self.read({})\n'.format(each_input_param_name, each_input_param_name))
+                    param_init_lines += ('            {} = self.read_file({})\n'.format(each_input_param_name, each_input_param_name))
                 elif self.input_params[each_input_param_name]['type'] == 'float':
                     param_init_lines += ('            {} = float({})\n'.format(each_input_param_name, each_input_param_name))
                 elif self.input_params[each_input_param_name]['type'] == 'int':
@@ -129,8 +130,9 @@ class AlgorithmContainerConfigParser:
         try:
             with open(os.path.join(self.cur_dir, 'algorithm-deploy-compose.template'), 'r') as f:
                 templates = f.read()
+            lower_name = self.algorithm_name.replace('_', '-').lower()
             templates = templates.format(
-                self.algorithm_name, self.algorithm_name, self.algorithm_version, self.algorithm_name, self.algorithm_version
+                self.algorithm_name, lower_name, self.algorithm_version, self.algorithm_name, self.algorithm_version
             )
             with open(os.path.join(self.service_dir, 'vsource_deploy_compose.yaml'), 'w') as f:
                 f.write(templates)
@@ -146,7 +148,8 @@ class AlgorithmContainerConfigParser:
             with open(os.path.join(self.cur_dir, 'algorithm-start.template'), 'r') as f:
                 templates = f.read()
             with open(os.path.join(self.service_dir, 'vsource_start.sh'), 'w') as f:
-                templates = templates.format(self.algorithm_name, self.algorithm_version)
+                lower_name = self.algorithm_name.replace('_', '-').lower()
+                templates = templates.format(lower_name, self.algorithm_version)
                 f.write(templates)
 
             with open(os.path.join(self.cur_dir, 'algorithm-stop.template'), 'r') as f:
